<?php

namespace Lightweb_Media\UPD_Amazon\Admin;

defined( 'ABSPATH' ) || exit;

use Automattic\Jetpack\Constants;
use Lightweb_Media\UPD_Amazon\Abstracts\UPD_Amazon_Singleton_Abstract;
use Lightweb_Media\UPD_Amazon\Admin\Interfaces\UPD_Amazon_Admin_Assets_Interface;

/**
 * Class UPD_Amazon_Admin_Assets
 *
 * @package Lightweb_Media\UPD_Amazon\Admin
 */
class UPD_Amazon_Admin_Assets extends UPD_Amazon_Singleton_Abstract implements UPD_Amazon_Admin_Assets_Interface {

	/**
	 * The suffix for script & style debugging in WordPress
	 *
	 * @var string
	 */
	private string $scripts_suffix;

	/**
	 * The file path to the css dir
	 *
	 * @var string
	 */
	private string $css_dir;

	/**
	 * The file path to the admin css dir
	 *
	 * @var string
	 */
	private string $admin_css_dir;

	/**
	 * The file path to the js dir
	 *
	 * @var string
	 */
	private string $js_dir;

	/**
	 * The file path to the admin js dir
	 *
	 * @var string
	 */
	private string $admin_js_dir;

	/**
	 * UPD_Amazon_Admin_Assets constructor
	 */
	public function __construct() {
		if ( is_admin() ) {
			$this->scripts_suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
			$this->css_dir        = Constants::get_constant( 'UPD_AMAZON_ASSETS_URL' ) . 'css' . DIRECTORY_SEPARATOR;
			$this->admin_css_dir  = $this->css_dir . 'admin' . DIRECTORY_SEPARATOR;
			$this->js_dir         = Constants::get_constant( 'UPD_AMAZON_ASSETS_URL' ) . 'js' . DIRECTORY_SEPARATOR;
			$this->admin_js_dir   = $this->js_dir . 'admin' . DIRECTORY_SEPARATOR;

			$this->init_hooks();
		}
	}

	/**
	 * Init / set up hooks
	 */
	private function init_hooks(): void {
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts_action' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_styles_action' ) );
	}

	/**
	 * Register admin scripts
	 */
	public function admin_enqueue_scripts_action(): void {
		$screen    = get_current_screen();
		$screen_id = $screen->id ?? '';
		$version   = Constants::get_constant( 'UPD_AMAZON_VERSION' );

		wp_register_script(
			'upd-amazon-admin',
			$this->admin_js_dir . 'upd-amazon-admin' . $this->scripts_suffix . '.js',
			array(
				'jquery',
			),
			$version
		);

		if ( $screen_id === 'toplevel_page_uralp-upd-amazon-plugin' ) {
			wp_enqueue_script( 'upd-amazon-admin' );

			wp_localize_script(
				'upd-amazon-admin',
				'upd_amazon_admin',
				array(
					'nonce' => esc_js( wp_create_nonce( 'upd-amazon' ) ),
				)
			);
		}
	}

	/**
	 * Register admin styles
	 */
	public function admin_enqueue_styles_action(): void {
		$screen    = get_current_screen();
		$screen_id = $screen->id ?? '';
		$version   = Constants::get_constant( 'UPD_AMAZON_VERSION' );

		wp_register_style(
			'upd-amazon-admin',
			$this->admin_css_dir . 'upd-amazon-admin' . $this->scripts_suffix . '.css',
			array(),
			$version
		);

		if ( $screen_id === 'toplevel_page_uralp-upd-amazon-plugin' ) {
			wp_enqueue_style( 'upd-amazon-admin' );
		}
	}
}
