<?php

namespace Lightweb_Media\UPD_Amazon;

defined( 'ABSPATH' ) || exit;

use Automattic\Jetpack\Constants;
use Lightweb_Media\Lightweb_Media_Plugin_Sidebar\LWM_Plugin_Sidebar;
use Lightweb_Media\UPD_Amazon\Abstracts\UPD_Amazon_Singleton_Abstract;
use Lightweb_Media\UPD_Amazon\Admin\UPD_Amazon_Admin;
use Lightweb_Media\UPD_Amazon\Interfaces\UPD_Amazon_Interface;

/**
 * Class UPD_Amazon
 *
 * @package Lightweb_Media\UPD_Amazon
 */
class UPD_Amazon extends UPD_Amazon_Singleton_Abstract implements UPD_Amazon_Interface {

	/**
	 * UPD_Amazon version
	 *
	 * @var string
	 */
	public string $version = '1.1.1';

	/**
	 * UPD_Amazon constructor
	 */
	public function __construct() {
		$this->define_constants();
		$this->includes();
		$this->init_hooks();

		// Register uninstall hook -> uninstall must be always possible, also if dependency is missing
		register_uninstall_hook( Constants::get_constant( 'UPD_AMAZON_PLUGIN_FILE' ), '\Lightweb_Media\UPD_Amazon\UPD_Amazon_Uninstall::uninstall' );

		// Register activation hook
		register_activation_hook( Constants::get_constant( 'UPD_AMAZON_PLUGIN_FILE' ), array( UPD_Amazon_Install::get_instance(), 'install' ) );
	}

	/**
	 * Init / set up hooks
	 */
	private function init_hooks(): void {
		add_action( 'plugins_loaded', array( $this, 'plugins_loaded_action' ) );
	}

	/**
	 * Define UPD_Amazon constants
	 */
	private function define_constants(): void {
		$this->define_constant( 'UPD_AMAZON_TEMPLATES_DIR', Constants::get_constant( 'UPD_AMAZON_ABSPATH' ) . 'templates' . DIRECTORY_SEPARATOR );
		$this->define_constant( 'UPD_AMAZON_ADMIN_TEMPLATES_DIR', Constants::get_constant( 'UPD_AMAZON_TEMPLATES_DIR' ) . 'admin' . DIRECTORY_SEPARATOR );
		$this->define_constant( 'UPD_AMAZON_PLUGIN_URL', untrailingslashit( plugins_url( DIRECTORY_SEPARATOR, Constants::get_constant( 'UPD_AMAZON_PLUGIN_FILE' ) ) ) . DIRECTORY_SEPARATOR );
		$this->define_constant( 'UPD_AMAZON_ASSETS_URL', Constants::get_constant( 'UPD_AMAZON_PLUGIN_URL' ) . 'assets' . DIRECTORY_SEPARATOR );
		$this->define_constant( 'UPD_AMAZON_VERSION', $this->version );
	}

	/**
	 * Define constant if not already set
	 *
	 * @param string $name
	 * @param string|bool $value
	 */
	private function define_constant( string $name, $value ): void {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	/**
	 * Include core functions used plugin wide
	 */
	private function includes(): void {
		$includes = array(
			'core',
		);

		foreach ( $includes as $include ) {
			include_once Constants::get_constant( 'UPD_AMAZON_ABSPATH' ) . 'includes' . DIRECTORY_SEPARATOR . 'functions' . DIRECTORY_SEPARATOR . 'upd-amazon-' . $include . '-functions.php';
		}

		$action_scheduler = Constants::get_constant( 'UPD_AMAZON_ABSPATH' ) . 'vendor/woocommerce/action-scheduler/action-scheduler.php';

		if ( file_exists( $action_scheduler ) ) {
			include_once Constants::get_constant( 'UPD_AMAZON_ABSPATH' ) . 'vendor/woocommerce/action-scheduler/action-scheduler.php';
		}
	}

	/**
	 * Default plugins loaded action
	 */
	public function plugins_loaded_action(): void {
		$this->main_init_classes();
	}

	/**
	 * Init important main classes
	 */
	private function main_init_classes(): void {
		UPD_Amazon_Admin::get_instance();
		UPD_Amazon_Cron_Jobs::get_instance();
		LWM_Plugin_Sidebar::get_instance(); // Load initially to register translation files
	}
}
