<?php

defined( 'ABSPATH' ) || exit;

if ( ! function_exists( 'upd_amazon_memory_time_limit_reached' ) ) {
	/**
	 * Checks if a current given process has reached memory or time limit during execution
	 *
	 * @param float $offset
	 *
	 * @return bool
	 */
	function upd_amazon_memory_time_limit_reached( float $offset = 0.1 ): bool {
		$server_memory_limit  = ini_get( 'memory_limit' );
		$memory_limit_bytes   = wp_convert_hr_to_bytes( $server_memory_limit );
		$max_execution_time   = (int ) ini_get( 'max_execution_time' );
		$current_memory_usage = memory_get_peak_usage( true );

		// Calculate the remaining memory before reaching the limit or assume no limit if both are not set.
		$remaining_memory = ( $memory_limit_bytes === - 1 ) ? PHP_INT_MAX : $memory_limit_bytes - $current_memory_usage;

		// Calculate the time remaining before reaching the time limit or assume no limit if both are not set.
		$remaining_time = $max_execution_time - ( microtime( true ) - $_SERVER["REQUEST_TIME_FLOAT"] );

		// Check if either memory or time limit is close to expiring (only if a limit is set).
		return ( ( $memory_limit_bytes !== - 1 && $remaining_memory <= $offset * $memory_limit_bytes ) ||
		         ( $max_execution_time !== - 1 && $remaining_time <= $offset * $max_execution_time ) );
	}
}
