<?php

namespace Lightweb_Media\UPD_Amazon\Interfaces;

defined( 'ABSPATH' ) || exit;

/**
 * Interface UPD_Amazon_Cron_Jobs_Interface
 *
 * @package Lightweb_Media\UPD_Amazon\Interfaces
 */
interface UPD_Amazon_Cron_Jobs_Interface {

	/**
	 * UPD_Amazon_Cron_Jobs constructor
	 */
	public function __construct();

	/**
	 * Runs scheduled expanding of shortened Amazon links
	 *
	 * @param int $posts_idx
	 */
	public function upd_amazon_expand_action( int $posts_idx ): void;

	/**
	 * Runs scheduled update from short to long links including the affiliate tag
	 *
	 * @param string $new_id
	 * @param int $posts_idx
	 */
	public function upd_amazon_update_action( string $new_id, int $posts_idx ): void;

	/**
	 * Runs scheduled adding of the no follow attribute to the links
	 *
	 * @param int $posts_idx
	 */
	public function upd_amazon_no_follow_action( int $posts_idx ): void;

	/**
	 * Runs scheduled removing of the Amazon affiliate links
	 *
	 * @param int $posts_idx
	 */
	public function upd_amazon_no_affiliate_action( int $posts_idx ): void;

	/**
	 * Runs a cron immediately by skipping any schedule
	 *
	 * @param string $cron
	 * @param array $args
	 */
	public function run_cron( string $cron, array $args = array() ): void;

	/**
	 * Schedules a single event
	 *
	 * @param int $timestamp
	 * @param string $hook
	 * @param bool $check_scheduled
	 * @param array $args
	 */
	public function schedule_single( int $timestamp, string $hook, bool $check_scheduled = true, array $args = array() ): void;

	/**
	 * Schedules a recurring event
	 *
	 * @param int $timestamp
	 * @param string $recurrence
	 * @param string $hook
	 * @param bool $check_scheduled
	 * @param array $args
	 */
	public function schedule_recurring( int $timestamp, string $recurrence, string $hook, bool $check_scheduled = true, array $args = array() ): void;

	/**
	 * Clears scheduled hook
	 *
	 * @param string $hook
	 *
	 * @return void
	 */
	public function clear( string $hook ): void;

	/**
	 * Check if an event is already scheduled
	 *
	 * @param string $hook
	 * @param array $args
	 *
	 * @return bool
	 */
	public function is_scheduled( string $hook, array $args = array() ): bool;
}
