<?php

defined( 'ABSPATH' ) || exit;

use Lightweb_Media\Lightweb_Media_Plugin_Sidebar\LWM_Plugin_Sidebar;
use Lightweb_Media\UPD_Amazon\UPD_Amazon_Search_Replacer;

?>
<div class="wrap upd-amazon">
	<div class="upd-amazon-page-content has-cells">
		<div class="upd-amazon-page-cell upd-amazon-page-cell-full">
			<h1>Search & Replace Affiliate Links for Amazon</h1>
			<form id="upd-amazon-plugin-form" method="post">
				<table class="form-table">
					<tbody>
					<tr id="progress-row" style="display: none;">
						<th></th>
						<td>
							<h4>Current Progress</h4>
							<div class="meter">
								<span class="progress-bar" style="width: 100%"></span>
							</div>
							<h4 id="progress-result"></h4>
							<b>
								<h5>Please wait until the current operation is complete before running the next operation. If you have a big site, this can take some time.</h5>
							</b>
						</td>
					</tr>
					<tr id="response-msg-row" style="display: none;">
						<th></th>
						<td>
							<span style="font-weight: 600; font-size: 14px;" id="response-msg"></span>
						</td>
					</tr>
					<tr>
						<th>Step 1: Backing Up Your Site</th>
						<td>
							<p class="description">
								Before making any changes to Amazon affiliate links on your site, make sure to take a backup of your entire site. We highly recommend using trusted backup plugins such as <a
										target="_blank" href="https://wordpress.org/plugins/all-in-one-wp-migration/">All In One Migration</a>, or <a target="_blank" href="https://wordpress.org/plugins/updraftplus/">Updraft</a>.
							</p>
							<p class="description">Make sure to do this step before you use this plugin.</p>
						</td>
					</tr>
					<tr>
						<th>
							Step 2: Enter New Amazon Tracking ID Tag
						</th>
						<td>
							<p class="description">
								Create an Amazon Affiliate ID tag from your Amazon Associates dashboard. As an example, it should be in the following formats depending on your geography:
							</p>
							<ul class="ul-disc">
								<li>Amazon USA: UNIQUEID-20</li>
								<li>Amazon CA: UNIQUEID-20</li>
								<li>Amazon UK: UNIQUEID-21</li>
							</ul>
						</td>
					</tr>
					<tr>
						<th></th>
						<td>
							<?php
							$job = UPD_Amazon_Search_Replacer::get_instance()->get_last_job();

							if ( $job && ! empty( $job['keyword'] ) ) {
								echo "<input type='text' id='new-id' placeholder='Enter tracking ID tag' value='" . $job['keyword'] . "' name='new-id'>";
							} else {
								echo "<input type='text' id='new-id' placeholder='Enter tracking ID tag' name='new-id'>";
							}
							?>
						</td>
					</tr>
					<tr>
						<th colspan="2">Step 3: Find, Replace, and Update Amazon Links</th>
					</tr>
					<tr>
						<th>Option 1: Expand Shortened Amazon Links</th>
						<td>
							<p class="description">
								The website uses shortened links (e.g., amzn.to) and you would like to bulk replace them with long Amazon links with your tracking ID tag. For example:
							</p>
							<ul class="ul-disc">
								<li><strong>Short form:</strong> https://amzn.to</li>
								<li><strong>Long form:</strong> https://www.amazon.com/dp/PRODUCTASIN?tag=TEST123-20</li>
							</ul>
							<br>
							<p class="description">
								<i>Hint:</i> This will save you countless hours from manually changing shortened links to long links.
							</p>
							<br>
							<?php submit_button( 'Expand', 'primary', 'expand-btn', false ) ?>
						</td>
					</tr>
					<tr>
						<th>Option 2: Add or Replace Existing ID Tag</th>
						<td>
							<p class="description">
								The website already has long Amazon links and you would like to bulk replace them with a new ID tag. For example, you are using ID tag “TEST123-20”. You would like to change to
								“NEW123-20”.
							</p>
							<br>
							<p class="description">
								<i>Tip:</i> This is useful if you want to change tracking to a new tag you manage, or you recently purchase/sold a site and need to change the ID tag.
							</p>
							<br>
							<?php submit_button( 'Update', 'primary', 'update-btn', false ) ?>
						</td>
					</tr>
					<tr>
						<th>Option 3: Add NoFollow Link Attribute</th>
						<td>
							<p class="description">Add rel=”nofollow” attribute to all Amazon affiliate links</p>
							<br>
							<?php submit_button( 'Add No follow', 'primary', 'no_follow-btn', false ) ?>
						</td>
					</tr>
					<tr>
						<th>Option 4: Remove Amazon Affiliate ID Tag</th>
						<td>
							<p class="description">Remove existing Amazon affiliate ID tags from all links</p>
							<br>
							<p class="description">
								<i>Tip:</i> This will not remove the Amazon links. It will only remove the affiliate ID tag (i.e., TEST123-20 will be removed), thus making that non-affiliate links.
							</p>
							<br>
							<?php submit_button( 'Make non-affiliate', 'primary', 'no_affiliate-btn', false ) ?>
						</td>
					</tr>
					</tbody>
				</table>
			</form>
		</div>
		<?php
		LWM_Plugin_Sidebar::get_instance()->output();
		?>
	</div>
</div>
